"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.isValid = isValid;
exports.isEmptyElement = isEmptyElement;
exports.isVueSkipInstance = isVueSkipInstance;
exports.isValidElement = isValidElement;
exports.filterEmpty = filterEmpty;
exports.cloneElement = cloneElement;
exports.cloneVNodes = cloneVNodes;
exports.isString = isString;
exports.getPropByPath = getPropByPath;
exports.toArray = toArray;
exports.flattenChildren = void 0;
var _vue = require("vue");
function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;
    for(var i = 0, arr2 = new Array(len); i < len; i++)arr2[i] = arr[i];
    return arr2;
}
function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}
function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _iterableToArray(iter) {
    if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
}
function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _objectSpread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}
function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}
var _typeof = function(obj) {
    "@swc/helpers - typeof";
    return obj && typeof Symbol !== "undefined" && obj.constructor === Symbol ? "symbol" : typeof obj;
};
function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(n);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}
function isValid(value) {
    return value !== undefined && value !== null && value !== '';
}
function isEmptyElement(c) {
    return c.type === Comment || c.type === _vue.Fragment && c.children.length === 0 || c.type === Text && c.children.trim() === '';
}
function isVueSkipInstance(element) {
    return element ? element.__v_skip : false;
}
function isValidElement(element) {
    return (0, _vue).isVNode(element) && _typeof(element.type) !== 'symbol' // remove text node
    ;
}
var flattenChildren = function() {
    var children = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : [], filterEmpty1 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true;
    var temp = Array.isArray(children) ? children : [
        children
    ];
    var res = [];
    temp.forEach(function(child) {
        if (Array.isArray(child)) {
            var _res;
            (_res = res).push.apply(_res, _toConsumableArray(flattenChildren(child, filterEmpty1)));
        } else if (child && child.type === _vue.Fragment) {
            var _res1;
            (_res1 = res).push.apply(_res1, _toConsumableArray(flattenChildren(child.children, filterEmpty1)));
        } else if (child && (0, _vue).isVNode(child)) {
            if (filterEmpty1 && !isEmptyElement(child)) {
                res.push(child);
            } else if (!filterEmpty1) {
                res.push(child);
            }
        } else if (isValid(child)) {
            res.push(child);
        }
    });
    return res;
};
exports.flattenChildren = flattenChildren;
function filterEmpty() {
    var children = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : [];
    var res = [];
    children.forEach(function(child) {
        if (Array.isArray(child)) {
            var _res;
            (_res = res).push.apply(_res, _toConsumableArray(child));
        } else if (child.type === _vue.Fragment) {
            var _res2;
            (_res2 = res).push.apply(_res2, _toConsumableArray(child.children));
        } else {
            res.push(child);
        }
    });
    return res.filter(function(c) {
        return !isEmptyElement(c);
    });
}
function cloneElement(vnode) {
    var nodeProps = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, override = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : true, mergeRef = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : false;
    var ele = vnode;
    if (Array.isArray(vnode)) {
        ele = filterEmpty(vnode)[0];
    }
    if (!ele) {
        return null;
    }
    var node = (0, _vue).cloneVNode(ele, nodeProps, mergeRef);
    // cloneVNode内部是合并属性，这里改成覆盖属性
    node.props = override ? _objectSpread({}, node.props, nodeProps) : node.props;
    return node;
}
function cloneVNodes(vnodes) {
    var nodeProps = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, override = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : true;
    return vnodes.map(function(vnode) {
        return cloneElement(vnode, nodeProps, override);
    });
}
function isString(arg) {
    return typeof arg === 'string';
}
function getPropByPath(obj, namePathList, strict) {
    var tempObj = obj;
    var keyArr = namePathList;
    var i = 0;
    try {
        for(var len = keyArr.length; i < len - 1; ++i){
            if (!tempObj && !strict) break;
            var key = keyArr[i];
            if (key in tempObj) {
                tempObj = tempObj[key];
            } else {
                if (strict) {
                    throw Error('please transfer a valid name path to form item!');
                }
                break;
            }
        }
        if (strict && !tempObj) {
            throw Error('please transfer a valid name path to form item!');
        }
    } catch (error) {
        console.error('please transfer a valid name path to form item!');
    }
    return {
        o: tempObj,
        k: keyArr[i],
        v: tempObj ? tempObj[keyArr[i]] : undefined
    };
}
function toArray(value) {
    if (value === undefined || value === null) {
        return [];
    }
    return Array.isArray(value) ? value : [
        value
    ];
}
